@@ -642,7 +642,7 @@ class Profile(LinkedIn):
         }
         return pd.DataFrame([result])
 
-    def get_posts(self, profile_url=None, profile_urn=None):
+    def get_posts_stats(self, profile_url=None, profile_urn=None):
         params = {}
         if profile_url:
             params["profile_url"] = profile_url
@@ -761,8 +761,14 @@ class Message(LinkedIn):
         df = pd.DataFrame(res_json)
         return df.reset_index(drop=True)
 
-    def get_messages(self, conversation_urn, start=0, limit=-1, count=20):
-        req_url = f"{LINKEDIN_API}/message/geMessages?conversation_urn={conversation_urn}&start={start}&limit={limit}&count{count}"
+    def get_messages(
+        self, conversation_url=None, conversation_urn=None, start=0, limit=-1, count=20
+    ):
+        req_url = f"{LINKEDIN_API}/message/geMessages?start={start}&limit={limit}&count{count}"
+        if conversation_url:
+            req_url += f"&conversation_url={conversation_url}"
+        if conversation_urn:
+            req_url += f"&conversation_urn={conversation_urn}"
         headers = {"Content-Type": "application/json"}
         res = requests.post(req_url, json=self.cookies, headers=headers)
         try:
@@ -884,7 +890,7 @@ class Post(LinkedIn):
                     break
         return result
 
-    def get_info(self, post_url=None, activity_id=None):
+    def get_stats(self, post_url=None, activity_id=None):
         if post_url is not None:
             activity_id = self.__get_post_urn(post_url)
         if activity_id is None:
